@@ -18,9 +18,9 @@ lcpList<- function(sim){
     return(invisible(sim))
   }
   ##Get a list of of cell indexs for to and from points
-  paths.matrix <- cbind(raster::cellFromXY(sim$costSurface,
+  paths.matrix <- cbind(terra::cellFromXY(sim$costSurface,
                                          sf::st_coordinates(sim$landings)), 
-                      raster::cellFromXY(sim$costSurface, sim$roads.close.XY))
+                      terra::cellFromXY(sim$costSurface, sim$roads.close.XY))
   
   sim$paths.list <- split(paths.matrix, 1:nrow(paths.matrix))
   
